Struct StoredBlockAccessList
pub struct StoredBlockAccessList { /* private fields */ }Expand description
Stored block access list value.
Implementations
impl StoredBlockAccessList
impl StoredBlockAccessList
pub fn new(raw: Bytes) -> StoredBlockAccessList
pub fn new(raw: Bytes) -> StoredBlockAccessList
Creates a stored BAL from raw bytes.
pub const fn new_unchecked(
hash: FixedBytes<32>,
raw: Bytes,
) -> StoredBlockAccessList
pub const fn new_unchecked( hash: FixedBytes<32>, raw: Bytes, ) -> StoredBlockAccessList
Creates a stored BAL from its hash and raw bytes without verifying that they match.
pub const fn hash(&self) -> FixedBytes<32>
pub const fn hash(&self) -> FixedBytes<32>
Returns the stored hash without verifying it against the raw bytes.
pub fn into_raw(self) -> Bytes
pub fn into_raw(self) -> Bytes
Consumes the stored BAL and returns its raw bytes.