pub struct StaticFileCursor<'a>(/* private fields */);Expand description
Cursor of a static file segment.
Implementations
Sourceimpl<'a> StaticFileCursor<'a>
impl<'a> StaticFileCursor<'a>
Sourcepub fn new(
jar: &'a NippyJar<SegmentHeader>,
reader: Arc<DataReader>,
) -> ProviderResult<Self>
pub fn new( jar: &'a NippyJar<SegmentHeader>, reader: Arc<DataReader>, ) -> ProviderResult<Self>
Returns a new StaticFileCursor.
Sourcepub fn number(&self) -> Option<u64>
pub fn number(&self) -> Option<u64>
Returns the current BlockNumber or TxNumber of the cursor depending on the kind of
static file segment.
Sourcepub fn get(
&mut self,
key_or_num: KeyOrNumber<'_>,
mask: usize,
) -> ProviderResult<Option<Vec<&[u8]>>>
pub fn get( &mut self, key_or_num: KeyOrNumber<'_>, mask: usize, ) -> ProviderResult<Option<Vec<&[u8]>>>
Gets a row of values.
Sourcepub fn get_one<M: ColumnSelectorOne>(
&mut self,
key_or_num: KeyOrNumber<'_>,
) -> ProviderResult<Option<M::FIRST>>
pub fn get_one<M: ColumnSelectorOne>( &mut self, key_or_num: KeyOrNumber<'_>, ) -> ProviderResult<Option<M::FIRST>>
Gets one column value from a row.
Sourcepub fn get_two<M: ColumnSelectorTwo>(
&mut self,
key_or_num: KeyOrNumber<'_>,
) -> ProviderResult<Option<(M::FIRST, M::SECOND)>>
pub fn get_two<M: ColumnSelectorTwo>( &mut self, key_or_num: KeyOrNumber<'_>, ) -> ProviderResult<Option<(M::FIRST, M::SECOND)>>
Gets two column values from a row.
Sourcepub fn get_three<M: ColumnSelectorThree>(
&mut self,
key_or_num: KeyOrNumber<'_>,
) -> ProviderResult<Option<(M::FIRST, M::SECOND, M::THIRD)>>
pub fn get_three<M: ColumnSelectorThree>( &mut self, key_or_num: KeyOrNumber<'_>, ) -> ProviderResult<Option<(M::FIRST, M::SECOND, M::THIRD)>>
Gets three column values from a row.
Methods from Deref<Target = NippyJarCursor<'a, SegmentHeader>>
Sourcepub fn row_by_number(
&mut self,
row: usize,
) -> Result<Option<Vec<&[u8]>>, NippyJarError>
pub fn row_by_number( &mut self, row: usize, ) -> Result<Option<Vec<&[u8]>>, NippyJarError>
Returns a row by its number.
Sourcepub fn next_row(&mut self) -> Result<Option<Vec<&[u8]>>, NippyJarError>
pub fn next_row(&mut self) -> Result<Option<Vec<&[u8]>>, NippyJarError>
Returns the current value and advances the row.
Sourcepub fn row_by_number_with_cols(
&mut self,
row: usize,
mask: usize,
) -> Result<Option<Vec<&[u8]>>, NippyJarError>
pub fn row_by_number_with_cols( &mut self, row: usize, mask: usize, ) -> Result<Option<Vec<&[u8]>>, NippyJarError>
Returns a row by its number by using a mask to only read certain columns from the row.
Sourcepub fn next_row_with_cols(
&mut self,
mask: usize,
) -> Result<Option<Vec<&[u8]>>, NippyJarError>
pub fn next_row_with_cols( &mut self, mask: usize, ) -> Result<Option<Vec<&[u8]>>, NippyJarError>
Returns the current value and advances the row.
Uses a mask to only read certain columns from the row.