Struct StoragesHistory
pub struct StoragesHistory { /* private fields */ }Expand description
Stores pointers to block number changeset with changes for each storage key.
Last shard key of the storage will contain u64::MAX BlockNumber,
this would allows us small optimization on db access when change is in plain state.
Imagine having shards as:
Address | StorageKey | 100Address | StorageKey | u64::MAX
What we need to find is number that is one greater than N. Db seek function allows us to fetch
the shard that equal or more than asked. For example:
- For N=50 we would get first shard.
- for N=150 we would get second shard.
- If max block number is 200 and we ask for N=250 we would fetch last shard and know that needed entry is in
StoragePlainState. - If there were no shard we would get
Noneentry or entry of different storage key.
Marker type representing a database table mapping StorageShardedKey to BlockNumberList.